pub(in protocol::external) struct AddrV1 {
untrusted_last_seen: DateTime32,
untrusted_services: PeerServices,
addr: PeerSocketAddr,
}Expand description
The first format used for Bitcoin node addresses.
Contains a node address, its advertised services, and last-seen time.
This struct is serialized and deserialized into addr (v1) messages.
Fields
untrusted_last_seen: DateTime32The unverified “last seen time” gossiped by the remote peer that sent us this address.
See the MetaAddr::last_seen method for details.
untrusted_services: PeerServicesThe unverified services for the peer at addr.
These services were advertised by the peer at addr,
then gossiped via another peer.
Security
untrusted_services on gossiped peers may be invalid due to outdated
records, older peer versions, or buggy or malicious peers.
addr: PeerSocketAddrThe peer’s canonical socket address. IPv4 addresses are serialized as an IPv4-mapped IPv6 address.